import { Component, OnInit, ViewChild } from '@angular/core';
import { OverAllService } from "../../overAll/overAll.service";
import {
    FormBuilder,
    FormGroup,
    Validators
} from '@angular/forms';
import {BasicKeyComponent} from "../basic-key/basic-key.component";
import { NzMessageService } from "ng-zorro-antd";
import {NewTypeComponent} from "../new-type/new-type.component";

@Component({
  selector: 'smart-basi-check',
  templateUrl: './basi-check.component.html',
  styles: []
})
export class BasiCheckComponent implements OnInit {
    @ViewChild('basicKey') basicKey:BasicKeyComponent;
    @ViewChild('newType') newType:NewTypeComponent;
    isCheck = false;
    hostId;   //主机ID
    interfaceList:any[];
    validateForm;
    checkList;  //监测点分类
    interval;    //间隔时长
    faultConditionList = [
        {
            code:'1',
            equal:'>=',
            value:'400',
        }
    ];   //危险阀值list
    conditionList = [
        {
            code:'1',
            equal:'>=',
            value:'400',
        }
    ];    //故障list
  constructor( private overAllSer: OverAllService,private fb: FormBuilder,
               private message: NzMessageService) { }

  ngOnInit() {
      this.validateForm = {
          itemExtend:{
              datatype: null,
              itemtype: null,
              multiple: null,
              storagevalue: null,
          },
          hostid:this.hostId,
          name: null,
          interfaceid: null,
          key_: null,
          value_type: null,
          type: null,
          units: null,
          history: null,
          trends: null,
          valuemapid: null,
          interval1: null,
          delay: null,
      };
  }

    //初始化信息
    showCheckModal(hostId){
        this.isCheck = true;
        this.hostId = hostId;
        this.validateForm = {
            itemExtend:{
                datatype: null,
                itemtype: null,
                multiple: null,
                storagevalue: null,
            },
            hostid:this.hostId,
            name: null,
            interfaceid: null,
            key_: null,
            value_type: null,
            type: null,
            units: null,
            history: null,
            trends: null,
            valuemapid: null,
            interval1: null,
            delay: null,
        };

        //主机接口
        this.overAllSer.getinterface(hostId).subscribe(
            (res)=>{
                this.interfaceList = res.data;
            }
        )
        this.getItemType();
    }

    //获取监测点分类
    getItemType(){
        //监测点分类
        const data = {
            "hostids":[]
        }
        data.hostids.push(this.hostId);
        this.overAllSer.findItemType(data).subscribe(
            (res)=>{
                this.checkList = res.data;
            }
        )
    }

    //添加
    handleCheckOk(): void {
        console.log(this.validateForm);
        this.overAllSer.create(this.validateForm).subscribe(
            (res)=>{
                if(res == 10000){
                    this.isCheck = false;
                }
                this.message.info(res.errMsg);
            },
            (err)=>{
                this.message.info('系统错误')
            }
        )
    }

    handleCheckCancel(): void {
        this.isCheck = false;
    }

    //键值查询
    showKeymodal(){
        this.basicKey.showKeyModal();
    }

    //新增分类
    showTypeModal(){
      this.newType.showModal('新建分类');
    }

    //添加分类
    addItemType(data){
        console.log(data);
        const obj = {
            hostid:this.hostId,
            name:data
        }
        this.overAllSer.createItemType(obj).subscribe(
            (res)=>{
                if(res.errCode == 10000){
                    this.message.info("添加成功");
                    this.getItemType();
                }else{
                    this.message.info(res.errMsg);
                }
            }
        )
    }

    //危险add
    addFault(){
      const demo = {
          and:'&',
          code:'1',
          equal:'>=',
          value:'400',
      }
      this.faultConditionList.push(demo);
    }

    //故障add
    addcondition(){
        const demo = {
            and:'&',
            code:'1',
            equal:'>=',
            value:'400',
        }
        this.conditionList.push(demo);
    }

    //危险delete
    deleteFault(index){
      this.faultConditionList.splice(index,1);
    }

    //故障delete
    deleteCondition(index){
        this.conditionList.splice(index,1);
    }

    getKey(keyValue):void{
      this.validateForm.key_ = keyValue;
    }


}
